:tocdepth: 2

abcvoting
=========

`abcvoting <https://github.com/martinlackner/abcvoting>`_ is a Python library 
of approval-based committee (ABC) rules.
ABC rules are also known as approval-based multi-winner rules.
The input of such rules are
`approval ballots <https://en.wikipedia.org/wiki/Approval_voting#/media/File:Approval_ballot.svg>`_.
We recommend the book
"`Multi-Winner Voting with Approval Preferences <https://arxiv.org/abs/2007.01795>`_"
by Lackner and Skowron as a detailed introduction to ABC rules and related research directions.
In addition, the
`survey by Faliszewski et al. <http://research.illc.uva.nl/COST-IC1205/BookDocs/Chapters/TrendsCOMSOC-02.pdf>`_
is useful as a more general introduction to committee voting.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   installation.rst
   intro-example.rst
   intro-abcrules.rst
   intro-computing-winning-committees.rst
   intro-properties.rst

.. toctree::
   :maxdepth: 3
   :caption: User reference:

   abcrules.rst
   fileio.rst
   generate.rst
   misc.rst
   output.rst
   preferences.rst
   properties.rst
   scores.rst

.. toctree::
   :maxdepth: 3
   :caption: Backmatter:

   howtocite.rst
   acks.rst
   GitHub repository <https://github.com/martinlackner/abcvoting>

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

